@@ -12,9 +12,12 @@ from .py_op_exceptions import (  # noqa: F401
     OPNotFoundException,
     OPGetItemException,
     OPGetDocumentException,
+    OPGetUserException,
+    OPGetGroupException,
+    OPGetVaultException,
+    OPListEventsException,
     OPInvalidDocumentException,
     OPSignoutException,
-    OPForgetException
+    OPForgetException,
+    OPConfigNotFoundException
 )
-
-from .py_op_exceptions import OPConfigNotFoundException  # noqa: F401
